You may be able to find older Commercial and Mercantile Court records in [The National Archives’ Catalogue](https://discovery.nationalarchives.gov.uk/){target="\_blank"} however the record may not be available online. You can read more about how to find older records in [the Civil Court cases: Kings/Queens bench division research guide](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/court-of-kings-bench-plea-side-and-kings-queens-bench-division-cases-1702-1998/){target="\_blank"}.
